%         Contents.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  matlab routines in the Analysis/Ctd directory
%
%            driver routines
%
%  DoLineCheck.m   - Calls plotCtdCasts for different cruises or station
%                    groups to see the cast location.  
%  DoPTSplots.m    - creates a series of T-S plots for different cruises and
%                    sets of stations. Also can create T-O2 plots. 
%                    Saves figures to postscript files. 
%  DoPlotsvsZ.m    - creates a series of plots of properties versus depth for
%                    different cruises and groups of stations.
%                    Saves figures to postscript files. 
%  DoAvgPlots.m    - creates a series of plots of the horizontal average of
%                    water properties versus depth for different cruises and 
%                    groups of stations. 
%                    Saves figures to postscript files. 
%  DoPlotsvsSig.m  - creates a series of plots of water properties versus 
%                    sigma for different cruises and groups of stations. 
%                    Saves figures to postscript files. 
%  DoMaps.m        - create a series of horizontal maps of variables on depth or
%                    density surfaces. 
%                    Saves figures to postscript files. 
%  DoPrintonMaps.m - create a series of horizontal maps of printed values of
%                    variables on depth or density surfaces.
%                    Saves figures to postscript files. 
%  DoSections.m    - create a series of contours plots of vertical sections
%                    of water properties for different cruises and groups of
%                    stations. 
%                    Saves figures to postscript files. 
% DoPrintonSections.m - create a series of vertical sections of water
%                    properties with values printed at the appropriate place
%                    and depth. 
%                    Saves figures to postscript files. 
%
%        Single task routines in subdirectory matlab
%
%  plotCtdStations.m - plots ctd station number at station location 
%                      on map with bathymetry.
%  plotCtdCasts.m    - plots ctd cast number at station location 
%                      on map with bathymetry.
%  plotXctdCasts.m   - plots xctd cast number at station location 
%                      on map with bathymetry
%  plotXbtCasts.m    - plots xbt cast number at station location 
%                      on map with bathymetry
%
%       vertical profile of properties
%
%  plotPTz.m    - plot vertical profile of potential temperature versus depth.
%  plotSz.m     - plot vertical profile of salinity versus depth.
%  plotSigmaz.m - plot vertical profile of potential density versus depth.
%  plotO2z.m    - plot vertical profile of dissolved oxygen versus depth.
%                 o2 units can be umol/kg or ml/l controlled by o2units.
%  plotPTsig.m  - plot vertical profile of potential temperature versus density.
%  plotSsig.m   - plot vertical profile of salinity versus density.
%  plotAvgPTz.m - plot horizontal average of potential temperature versus
%                 depth for a set of stations.
%                 Includes one standard deviation envelopes.
%  plotAvgSz.m  - plot horizontal average of salinity versus
%                 depth for a set of stations.
%                 Includes one standard deviation envelopes.
%
%          property-property plots
%
%  plotPTS.m  - plot potential temperature against salinity.
%  plotPTO2.m - plot dissolved oxygen versus potential temperature.
%               o2 units can be umol/kg or ml/l controlled by o2units.
%
%              horizontal maps
%
%  Tmap.m       - contour potential temperature on a given depth or density
%                 level at horizontal locations on a regional map.
%  Smap.m       - contour salinty on a given depth or density
%                 level at horizontal locations on a regional map.
%  O2map.m      - contour oxygen on a given depth or density
%                 level at horizontal locations on a regional map.
%  Sigmap.m     - contour potential density on a given depth or density
%                 level at horizontal locations on a regional map.
%  DynTopomap.m - contour dynamic topography on a regional map.
%                 plots surface dynamic topography relative to RefPress.
%  Tmaxmap.m    - contour maximum potential temperature below a given depth
%                 at horizontal locations on a regional map.
%  printTonMap.m   - print potential temperature on a given depth or density
%                    level at horizontal locations on a regional map.
%  printSonMap.m   - print salinty on a given depth or density
%                    level at horizontal locations on a regional map.
%  printO2onMap.m  - print oxygen on a given depth or density
%                    level at horizontal locations on a regional map.
%  printSigonMap.m - print potential density on a given depth or density
%                    level at horizontal locations on a regional map.
%  printDynTopomap.m - prints surface dynamic topography relative to
%                      RefPress on a regional map.
%
%            vertical sections
%
%  Tsection.m    - contour potential temperature from ctd on a vertical section.
%  Ssection.m    - contour salinity from ctd on a vertical section.
%  Sigsection.m  - contour potential density from ctd on a vertical section.
%  O2section.m   - contour dissolved from ctd on a vertical section.
%  printTonSection.m   - print potential temperature from ctd on a vertical section.
%  printSonSection.m   - print salinity from ctd on a vertical section.
%  printSigonSection.m - print potential density from ctd on a vertical section.
%  printO2onSection.m  - print dissolved oxygen from ctd on a vertical section.
%
%            Setup routines
%
%  SetDefaults.m - Sets all needed variables for plots. This routine should
%                  be called only once at the beginning of a session. 
%                  Individual variables can be changed as needed.
%                  Most changes are made in the Do<job> driver routines.
%  SetupPlots.m  - define lists of stations based on the cruise and the set
%                  of stations (Line) desired. Also sets plot size
%                  label locations and label strings
%                  Will recalculate grid values from lat,lon for FixGrid=1.
%                  Checks for missing grid values and will calculate from lat,lon
%  GetInfo.m     - reads ctd, xbt and xctd event files to get general information.
%
%           Support functions
%
%  castnum.m - returns a string with the cast number 
%              for use with reading data files. 
%              string includes leading zeros for numbers less than 100.
%  startup.m - points to basic matlab libraries.
%              needed for these routines.
%   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

